﻿using System;
using System.Collections;
using UnityEngine;

namespace Mod
{
	class InvincibilityPoison : PoisonSpreadBehaviour
	{
		readonly float Max = Mathf.Infinity;

		public override float SpreadSpeed
		{
			get
			{
				return Max;
			}
		}

		public override void Start()
		{
			Limb.gameObject.AddComponent<InvincibilityBehaviour>();
		}

		public InvincibilityPoison()
		{
		}
	}

	class InvincibilitySyringe : OldSyringeBehaviour
	{
		public override Type GetPoisonType()
		{
			return typeof(InvincibilityPoison);
		}
	}

	class InvincibilityBehaviour : MonoBehaviour
    {
		readonly float Max = Mathf.Infinity;

		LimbBehaviour Limb;

		void Awake()
        {
			Limb = gameObject.GetComponent<LimbBehaviour>();
		}

		void Update()
        {
			Limb.PhysicalBehaviour.BurnProgress = 0f;
			Limb.CirculationBehaviour.ImmuneToDamage = true;
			Limb.ImmuneToDamage = true;
			Limb.ExplodeLiquidAmount = Max;
			Limb.CirculationBehaviour.AddLiquid(Limb.GetOriginalBloodType(), Max);
            Limb.CirculationBehaviour.ForceSetAllLiquid(Max);
            Limb.gameObject.GetComponent<PhysicalBehaviour>().Disintegratable = false;
			Limb.BreakingThreshold = Max;
			Limb.IsDismembered = false;
			Limb.Frozen = false;
			Limb.CirculationBehaviour.BloodFlow = 100f;
			Limb.CirculationBehaviour.GunshotWoundCount = (ushort)0;
			Limb.CirculationBehaviour.StabWoundCount = (ushort)0;
			Limb.BaseStrength = 5f;
			Limb.BruiseCount = (ushort)0;
            Limb.IsLethalToBreak = false;
			Limb.Vitality *= 0f;
            Limb.Health = Max;
			Limb.InitialHealth = float.MaxValue - 1000f;
            Limb.RegenerationSpeed = Max;
			Limb.HealBone();
            Limb.CirculationBehaviour.IsPump = true;
            Limb.Numbness -= Max;
			Limb.Person.Consciousness = Max;
			Limb.Person.OxygenLevel = Max;
			Limb.Person.AdrenalineLevel = Max;
			foreach (var Death in gameObject.GetComponents<PermaDeathBehaviour>())
            {
                GameObject.Destroy(Death);
            }
			foreach (var Break in gameObject.GetComponents<BreakingBehaviour>())
            {
                GameObject.Destroy(Break);
            }
			foreach (var Crush in gameObject.GetComponents<CrushBehaviour>())
            {
                GameObject.Destroy(Crush);
            }
        }
    }
}
